@@ -95,7 +95,6 @@ static struct format {
 	{"measurefirst", &cfmt.measurefirst, FORMAT_I, 0},
 	{"measurefont", &cfmt.font_tb[MEASUREFONT], FORMAT_F, 2},
 	{"measurenb", &cfmt.measurenb, FORMAT_I, 0},
-	{"micronewps", &cfmt.micronewps, FORMAT_B, 0},
 	{"musicfont", &cfmt.musicfont, FORMAT_S, 1},
 	{"musicspace", &cfmt.musicspace, FORMAT_U, 0},
 	{"notespacingfactor", &cfmt.notespacingfactor, FORMAT_R, 1},
@@ -137,6 +136,7 @@ static struct format {
 	{"textfont", &cfmt.font_tb[TEXTFONT], FORMAT_F, 0},
 	{"textoption", &cfmt.textoption, FORMAT_I, 4},
 	{"textspace", &cfmt.textspace, FORMAT_U, 0},
+	{"tieheight", &cfmt.tieheight, FORMAT_R, 0},
 	{"titlecaps", &cfmt.titlecaps, FORMAT_B, 0},
 	{"titlefont", &cfmt.font_tb[TITLEFONT], FORMAT_F, 0},
 	{"titleformat", &cfmt.titleformat, FORMAT_S, 0},
@@ -379,6 +379,7 @@ void set_format(void)
 	f->textspace = 14 PT;
 	f->scale = 1.0;
 	f->slurheight = 1.0;
+	f->tieheight = 1.0;
 	f->maxshrink = 0.65;
 	f->breaklimit = 0.7;
 	f->stretchlast = 0.25;
